"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const index_1 = require("../index");
const clientCookieManager_1 = require("./clientCookieManager");
require("../constants/lang");
const debug_1 = require("../utils/debug");
class Client {
    /**
     * @param {ClientOptions} options - The options to use.
     */
    constructor(options) {
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "dailyReward", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "gameRecordCard", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "sprialAbyss", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "genshinActivity", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "characters", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "genshinUser", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "realTimeNotes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "travelDiary", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "redeemCode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "logined", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.options = {
            language: options?.language || "en-us" /* Language.EnglishUS */,
            cookieManager: options?.cookieManager || new clientCookieManager_1.ClientCookieManager(),
            cache: options?.cache || false,
            cacheOptions: {
                maxAge: options?.cacheOptions?.maxAge || 0,
            },
        };
        this.cookieManager = this.options.cookieManager;
        this.logined = false;
        (0, debug_1.setDebug)(options?.debug || false);
    }
    login(ltuid, ltoken) {
        if (this.logined)
            return;
        this.cookieManager.setCookie(ltuid, ltoken);
        const option = {
            cache: this.options.cache,
            cacheOptions: this.options.cacheOptions,
            defaultOptions: {
                language: this.options.language,
                cookie: this.cookieManager.get().cookie,
            },
            cookieManager: this.cookieManager,
        };
        this.dailyReward = new index_1.DailyRewards({
            defaultOptions: option.defaultOptions,
        });
        this.genshinActivity = new index_1.Activities(option);
        this.gameRecordCard = new index_1.GameRecordCard(option);
        this.sprialAbyss = new index_1.SpiralAbyss(option);
        this.genshinUser = new index_1.GenshinUser(option);
        this.realTimeNotes = new index_1.RealTimeNotes(option);
        this.characters = new index_1.Charcters(option);
        this.travelDiary = new index_1.TravelerDiary(option);
        this.redeemCode = new index_1.RedeemCode();
    }
    addCookies(cookies) {
        cookies.forEach((cookie) => {
            this.cookieManager.setCookie(cookie.ltuid, cookie.ltoken);
        });
    }
}
exports.Client = Client;
