"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GameRecordCard = void 0;
const request_1 = require("../utils/request");
const base_1 = require("./base");
const constants_1 = require("../constants/constants");
const alias_1 = require("../utils/alias");
const validate_1 = require("../utils/validate");
class GameRecordCard extends base_1.BaseRoute {
    /**
     * @param {string} uid HoYoLab Account ID
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = this.getFetchOptions(options);
        if (!(0, validate_1.validate)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_API_URL,
        });
        instance.setLanguage(language);
        const res = await instance.get("getGameRecordCard", {
            Cookie: cookie,
        }, {
            uid: uid,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(uid, data);
        }
        (0, alias_1.removeFromArrayObject)(data.list, ["h5_data_switches", "data_switches"]);
        return {
            list: data.list,
            currecnt: data.list[0],
        };
    }
}
exports.GameRecordCard = GameRecordCard;
