"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Activities = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const base_1 = require("./base");
const validate_1 = require("../utils/validate");
class Activities extends base_1.BaseRoute {
    /**
     * @param {string} uid The uid to set
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = this.getFetchOptions(options);
        if (!(0, validate_1.validate)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.get("activities", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            Cookie: cookie,
        }, {
            server: (0, getServer_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        const returnData = {
            sumo: data.activities[0].sumo.records,
            rogue: data.activities[1].rogue.records,
            channeller_slab_copy: data.activities[2].channeller_slab_copy,
            potion: data.activities[3].potion.records,
            sumo_second: data.activities[4].sumo_second.records,
            crystal: data.activities[5].crystal.records,
            perilous: data.activities[6].perilous.records,
            summer_v2: data.activities[7].summer_v2,
            spray: data.activities[8].spray,
        };
        if (this.cache) {
            this.cache.set(uid, returnData);
        }
        return returnData;
    }
}
exports.Activities = Activities;
