"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedeemCode = void 0;
const request_1 = require("../utils/request");
const constants_1 = require("../constants/constants");
const getServer_1 = require("../utils/getServer");
const validate_1 = require("../utils/validate");
class RedeemCode {
    /**
     * @description Redeem the code
     * @param {string} code The code to redeem
     */
    async redeem(code, options) {
        if (!(0, validate_1.redeemValidator)(code, options)) {
            throw new Error("No code or Cookie provided");
        }
        const { language, cookie, uid, cookie_token } = options;
        const instance = new request_1.request({
            route: constants_1.Genshin_Redeem_Code_URL,
        });
        const ac_id = cookie
            .split(";")
            .find((item) => item.includes("ltuid"))
            ?.split("=")[1];
        const res = await instance.get("", {
            Cookie: `${cookie}; cookie_token=${cookie_token}; account_id=${ac_id}`,
        }, {
            uid: uid,
            region: (0, getServer_1.checkServerRegion)(uid),
            lang: language,
            cdkey: code,
            game_biz: "hk4e_global",
        });
        const { data } = res;
        const isSuccessful = data.msg === "Redeemed successfully!";
        return {
            success: isSuccessful,
            msg: data.msg,
            special_shipping: data.special_shipping,
        };
    }
}
exports.RedeemCode = RedeemCode;
