"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TravelerDiary = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const base_1 = require("./base");
const constants_1 = require("../constants/constants");
const validate_1 = require("../utils/validate");
class TravelerDiary extends base_1.BaseRoute {
    /**
     * @param {string} uid Genshin Impact game uid.
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = this.getFetchOptions(options);
        if (!(0, validate_1.validate)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_DIARY_URL,
        });
        const res = await instance.get("month_info", {
            Cookie: cookie,
        }, {
            region: (0, getServer_1.checkServerRegion)(uid),
            uid: uid,
            lang: language,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(uid, data);
        }
        return data;
    }
    async fetchMonth(uid, options) {
        if (!(0, validate_1.getMonthValidator)(uid, options)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, month } = options;
        const instance = new request_1.request({
            route: constants_1.Genshin_Hoyolab_DIARY_URL,
        });
        const res = await instance.get("month_info", {
            Cookie: cookie,
        }, {
            region: (0, getServer_1.checkServerRegion)(uid),
            uid: uid,
            lang: language,
            month: month,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(`${uid}-${month}`, data);
        }
        return data;
    }
}
exports.TravelerDiary = TravelerDiary;
